{% load i18n admin_urls static admin_modify %}
<div class="card js-inline-admin-formset inline-group mt-3"
     id="{{ inline_admin_formset.formset.prefix }}-group"
     data-inline-type="tabular"
     data-inline-formset="{{ inline_admin_formset.inline_formset_data }}">
    <div class="card-status-top bg-primary"></div>
    <div class="tabular inline-related {% if forloop.last %}last-related{% endif %}">
        {{ inline_admin_formset.formset.management_form }}
        <fieldset class="module {{ inline_admin_formset.classes }}">
            <div class="card-header">
                {% if inline_admin_formset.formset.max_num == 1 %}
                    <h3 class="card-title">{{ inline_admin_formset.opts.verbose_name|capfirst }}</h3>
                {% else %}
                    <h3 class="card-title">{{ inline_admin_formset.opts.verbose_name_plural|capfirst }}</h3>
                {% endif %}
            </div>
            {{ inline_admin_formset.formset.non_form_errors }}
            <div class="table-responsive">
                <table class="table table-vcenter card-table">
                    <thead>
                        <tr>
                            <th class="original">#</th>
                            {% for field in inline_admin_formset.fields %}
                                <th class="column-{{ field.name }}{% if field.required %} required{% endif %}{% if field.widget.is_hidden %} hidden{% endif %}">
                                    {{ field.label|capfirst }}
                                    {% if field.help_text %}
                                        <img src="{% static "admin/img/icon-unknown.svg" %}"
                                             class="help help-tooltip"
                                             width="10"
                                             height="10"
                                             alt="({{ field.help_text|striptags }})"
                                             title="{{ field.help_text|striptags }}"/>
                                    {% endif %}
                                </th>
                            {% endfor %}
                            {% if inline_admin_formset.formset.can_delete and inline_admin_formset.has_delete_permission %}
                                <th class="w-1">{% translate "Delete?" %}</th>
                            {% endif %}
                        </tr>
                    </thead>

                    <tbody>
                        {% for inline_admin_form in inline_admin_formset %}
                            {% if inline_admin_form.form.non_field_errors %}
                                <tr class="row-form-errors">
                                    <td colspan="{{ inline_admin_form|cell_count }}">{{ inline_admin_form.form.non_field_errors }}</td>
                                </tr>
                            {% endif %}
                            <tr class="form-row {% if inline_admin_form.original or inline_admin_form.show_url %}has_original{% endif %}{% if forloop.last and inline_admin_formset.has_add_permission %} empty-form{% endif %}"
                                id="{{ inline_admin_formset.formset.prefix }}-{% if forloop.last and inline_admin_formset.has_add_permission %}empty{% else %}{{ forloop.counter0 }}{% endif %}">
                                <td class="original w-0">
                                    {% if inline_admin_form.original or inline_admin_form.show_url %}
                                        <p class="w-100">
                                            {% if inline_admin_form.original %}
                                                {{ inline_admin_form.original }}
                                                {% if inline_admin_form.model_admin.show_change_link and inline_admin_form.model_admin.has_registered_model %}
                                                    <a href="{% url inline_admin_form.model_admin.opts|admin_urlname:'change' inline_admin_form.original.pk|admin_urlquote %}"
                                                       class="{% if inline_admin_formset.has_change_permission %}inlinechangelink{% else %}inlineviewlink{% endif %}">
                                                        {% if inline_admin_formset.has_change_permission %}
                                                            {% translate "Change" %}
                                                        {% else %}
                                                            {% translate "View" %}
                                                        {% endif %}
                                                    </a>
                                                {% endif %}
                                            {% endif %}
                                            {% if inline_admin_form.show_url %}
                                                <a href="{{ inline_admin_form.absolute_url }}">{% translate "View on site" %}</a>
                                            {% endif %}
                                        </p>
                                    {% endif %}
                                    {% if inline_admin_form.needs_explicit_pk_field %}{{ inline_admin_form.pk_field.field }}{% endif %}
                                    {% if inline_admin_form.fk_field %}{{ inline_admin_form.fk_field.field }}{% endif %}
                                </td>
                                {% for fieldset in inline_admin_form %}
                                    {% for line in fieldset %}
                                        {% for field in line %}
                                            <td class="{% if field.field.name %}field-{{ field.field.name }}{% endif %}{% if field.field.is_hidden %} hidden{% endif %}">
                                                {% if field.is_readonly %}
                                                    <p>{{ field.contents }}</p>
                                                {% else %}
                                                    {{ field.field.errors.as_ul }}
                                                    {{ field.field }}
                                                {% endif %}
                                            </td>
                                        {% endfor %}
                                    {% endfor %}
                                {% endfor %}
                                {% if inline_admin_formset.formset.can_delete and inline_admin_formset.has_delete_permission %}
                                    <td class="delete w-1">
                                        {% if inline_admin_form.original %}{{ inline_admin_form.deletion_field.field }}{% endif %}
                                    </td>
                                {% endif %}
                            </tr>
                        {% endfor %}
                    </tbody>
                </table>
            </div>
        </fieldset>
    </div>
</div>
