{% extends "admin/index.html" %}
{% load i18n %}

{% block bodyclass %}
    {{ block.super }} app-{{ app_label }}
{% endblock bodyclass %}
{% if not is_popup %}
    {% block breadcrumbs %}
        <div class="page-pretitle">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">
                    <a href="{% url 'admin:index' %}">{% translate "Home" %}</a>
                </li>
                {% for app in app_list %}
                    <li class="breadcrumb-item {% if forloop.last %}active{% endif %}">
                        <a href="{{ app.url }}">{{ app.name }}</a>
                    </li>
                {% endfor %}
            </ol>
        </div>
    {% endblock breadcrumbs %}
{% endif %}
{% block sidebar %}
{% endblock sidebar %}
