<a onclick="toggleTheme()"
   href="javascript:void(0);"
   class="nav-link px-0 toggleTheme hide-theme-dark"
   data-bs-toggle="tooltip"
   data-bs-placement="bottom"
   aria-label="Enable dark mode"
   data-bs-original-title="Enable dark mode">
    <svg xmlns="http://www.w3.org/2000/svg" class="icon" width="24" height="24" viewBox="0 0 24 24" stroke-width="2" stroke="currentColor" fill="none" stroke-linecap="round" stroke-linejoin="round">
        <path stroke="none" d="M0 0h24v24H0z" fill="none" />
        <path d="M12 3c.132 0 .263 0 .393 0a7.5 7.5 0 0 0 7.92 12.446a9 9 0 1 1 -8.313 -12.454z" />
    </svg>
</a>
<a onclick="toggleTheme()"
   href="javascript:void(0);"
   class="nav-link px-0 toggleTheme hide-theme-light"
   data-bs-toggle="tooltip"
   data-bs-placement="bottom"
   aria-label="Enable light mode"
   data-bs-original-title="Enable light mode">
    <svg xmlns="http://www.w3.org/2000/svg" class="icon" width="24" height="24" viewBox="0 0 24 24" stroke-width="2" stroke="currentColor" fill="none" stroke-linecap="round" stroke-linejoin="round">
        <path stroke="none" d="M0 0h24v24H0z" fill="none" />
        <circle cx="12" cy="12" r="4"></circle>
        <path d="M3 12h1m8 -9v1m8 8h1m-9 8v1m-6.4 -15.4l.7 .7m12.1 -.7l-.7 .7m0 11.4l.7 .7m-12.1 -.7l-.7 .7" />
    </svg>
</a>
