{% if widget.type == 'checkbox' %}
    class="form-check-input {{ widget.attrs.class|stringformat:'s' }}"
{% elif widget.attrs.multiple %}
    class="form-select"
{% else %}
    class="form-control {{ widget.attrs.class|stringformat:'s' }}"
{% endif %}
