/*!
* Tabler v1.0.0-beta20 (https://tabler.io)
* @version 1.0.0-beta20
* @link https://tabler.io
* Copyright 2018-2023 The Tabler Authors
* Copyright 2018-2023 codecalm.net Paweł Kuna
* Licensed under MIT (https://github.com/tabler/tabler/blob/master/LICENSE)
*/
/* prettier-ignore */
/* prettier-ignore */
/* Functional styling;
 * These styles are required for noUiSlider to function.
 * You don't need to change these rules to apply your design.
 */
 .noUi-target,
 .noUi-target * {
   -webkit-touch-callout: none;
   -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
   -webkit-user-select: none;
   touch-action: none;
   -ms-user-select: none;
   -moz-user-select: none;
   user-select: none;
   box-sizing: border-box;
 }
 
 .noUi-target {
   position: relative;
 }
 
 .noUi-base,
 .noUi-connects {
   width: 100%;
   height: 100%;
   position: relative;
   z-index: 1;
 }
 
 /* Wrapper for all connect elements.
  */
 .noUi-connects {
   overflow: hidden;
   z-index: 0;
 }
 
 .noUi-connect,
 .noUi-origin {
   will-change: transform;
   position: absolute;
   z-index: 1;
   top: 0;
   right: 0;
   height: 100%;
   width: 100%;
   -ms-transform-origin: 0 0;
   -webkit-transform-origin: 0 0;
   -webkit-transform-style: preserve-3d;
   transform-origin: 0 0;
   transform-style: flat;
 }
 
 /* Offset direction
  */
 .noUi-txt-dir-rtl.noUi-horizontal .noUi-origin {
   left: 0;
   right: auto;
 }
 
 /* Give origins 0 height/width so they don't interfere with clicking the
  * connect elements.
  */
 .noUi-vertical .noUi-origin {
   top: -100%;
   width: 0;
 }
 
 .noUi-horizontal .noUi-origin {
   height: 0;
 }
 
 .noUi-handle {
   -webkit-backface-visibility: hidden;
   backface-visibility: hidden;
   position: absolute;
 }
 
 .noUi-touch-area {
   height: 100%;
   width: 100%;
 }
 
 .noUi-state-tap .noUi-connect,
 .noUi-state-tap .noUi-origin {
   transition: transform 0.3s;
 }
 
 .noUi-state-drag * {
   cursor: inherit !important;
 }
 
 /* Slider size and handle placement;
  */
 .noUi-horizontal {
   height: 18px;
 }
 
 .noUi-horizontal .noUi-handle {
   width: 34px;
   height: 28px;
   right: -17px;
   top: -6px;
 }
 
 .noUi-vertical {
   width: 18px;
 }
 
 .noUi-vertical .noUi-handle {
   width: 28px;
   height: 34px;
   right: -6px;
   bottom: -17px;
 }
 
 .noUi-txt-dir-rtl.noUi-horizontal .noUi-handle {
   left: -17px;
   right: auto;
 }
 
 /* Styling;
  * Giving the connect element a border radius causes issues with using transform: scale
  */
 .noUi-target {
   background: #FAFAFA;
   border-radius: 4px;
   border: 1px solid #D3D3D3;
   box-shadow: inset 0 1px 1px #F0F0F0, 0 3px 6px -5px #BBB;
 }
 
 .noUi-connects {
   border-radius: 3px;
 }
 
 .noUi-connect {
   background: #3FB8AF;
 }
 
 /* Handles and cursors;
  */
 .noUi-draggable {
   cursor: ew-resize;
 }
 
 .noUi-vertical .noUi-draggable {
   cursor: ns-resize;
 }
 
 .noUi-handle {
   border: 1px solid #D9D9D9;
   border-radius: 3px;
   background: #FFF;
   cursor: default;
   box-shadow: inset 0 0 1px #FFF, inset 0 1px 7px #EBEBEB, 0 3px 6px -3px #BBB;
 }
 
 .noUi-active {
   box-shadow: inset 0 0 1px #FFF, inset 0 1px 7px #DDD, 0 3px 6px -3px #BBB;
 }
 
 /* Handle stripes;
  */
 .noUi-handle:before,
 .noUi-handle:after {
   content: "";
   display: block;
   position: absolute;
   height: 14px;
   width: 1px;
   background: #E8E7E6;
   left: 14px;
   top: 6px;
 }
 
 .noUi-handle:after {
   left: 17px;
 }
 
 .noUi-vertical .noUi-handle:before,
 .noUi-vertical .noUi-handle:after {
   width: 14px;
   height: 1px;
   left: 6px;
   top: 14px;
 }
 
 .noUi-vertical .noUi-handle:after {
   top: 17px;
 }
 
 /* Disabled state;
  */
 [disabled] .noUi-connect {
   background: #B8B8B8;
 }
 
 [disabled].noUi-target,
 [disabled].noUi-handle,
 [disabled] .noUi-handle {
   cursor: not-allowed;
 }
 
 /* Base;
  *
  */
 .noUi-pips,
 .noUi-pips * {
   box-sizing: border-box;
 }
 
 .noUi-pips {
   position: absolute;
   color: #999;
 }
 
 /* Values;
  *
  */
 .noUi-value {
   position: absolute;
   white-space: nowrap;
   text-align: center;
 }
 
 .noUi-value-sub {
   color: #ccc;
   font-size: 10px;
 }
 
 /* Markings;
  *
  */
 .noUi-marker {
   position: absolute;
   background: #CCC;
 }
 
 .noUi-marker-sub {
   background: #AAA;
 }
 
 .noUi-marker-large {
   background: #AAA;
 }
 
 /* Horizontal layout;
  *
  */
 .noUi-pips-horizontal {
   padding: 10px 0;
   height: 80px;
   top: 100%;
   left: 0;
   width: 100%;
 }
 
 .noUi-value-horizontal {
   transform: translate(-50%, 50%);
 }
 
 .noUi-rtl .noUi-value-horizontal {
   transform: translate(50%, 50%);
 }
 
 .noUi-marker-horizontal.noUi-marker {
   margin-left: -1px;
   width: 2px;
   height: 5px;
 }
 
 .noUi-marker-horizontal.noUi-marker-sub {
   height: 10px;
 }
 
 .noUi-marker-horizontal.noUi-marker-large {
   height: 15px;
 }
 
 /* Vertical layout;
  *
  */
 .noUi-pips-vertical {
   padding: 0 10px;
   height: 100%;
   top: 0;
   left: 100%;
 }
 
 .noUi-value-vertical {
   transform: translate(0, -50%);
   padding-left: 25px;
 }
 
 .noUi-rtl .noUi-value-vertical {
   transform: translate(0, 50%);
 }
 
 .noUi-marker-vertical.noUi-marker {
   width: 5px;
   height: 2px;
   margin-top: -1px;
 }
 
 .noUi-marker-vertical.noUi-marker-sub {
   width: 10px;
 }
 
 .noUi-marker-vertical.noUi-marker-large {
   width: 15px;
 }
 
 .noUi-tooltip {
   display: block;
   position: absolute;
   border: 1px solid #D9D9D9;
   border-radius: 3px;
   background: #fff;
   color: #000;
   padding: 5px;
   text-align: center;
   white-space: nowrap;
 }
 
 .noUi-horizontal .noUi-tooltip {
   transform: translate(-50%, 0);
   left: 50%;
   bottom: 120%;
 }
 
 .noUi-vertical .noUi-tooltip {
   transform: translate(0, -50%);
   top: 50%;
   right: 120%;
 }
 
 .noUi-horizontal .noUi-origin > .noUi-tooltip {
   transform: translate(50%, 0);
   left: auto;
   bottom: 10px;
 }
 
 .noUi-vertical .noUi-origin > .noUi-tooltip {
   transform: translate(0, -18px);
   top: auto;
   right: 28px;
 }
 
 .noUi-target {
   border: 0;
   box-shadow: none;
   background: none;
   border-radius: 0;
   color: var(--tblr-primary);
 }
 
 .noUi-horizontal {
   height: 1.25rem;
   padding: 0.5rem 0;
 }
 
 .noUi-base {
   background: var(--tblr-border-color);
   border-radius: 1rem;
 }
 
 .noUi-handle {
   width: 1rem;
   height: 1rem;
   border: 2px var(--tblr-border-style) #ffffff;
   box-shadow: 0 0.1rem 0.25rem rgba(0, 0, 0, 0.1);
   border-radius: 1rem;
   background: currentColor;
   outline: 0;
 }
 .noUi-handle:before, .noUi-handle:after {
   content: none;
 }
 .noUi-horizontal .noUi-handle {
   width: 1rem;
   height: 1rem;
   top: -0.5rem;
   right: -0.5rem;
   margin: 1px 1px 0 0;
 }
 .noUi-handle.noUi-active, .noUi-handle:focus {
   box-shadow: 0 0 0 1px #f6f8fb, 0 0 0 0.25rem rgba(var(--tblr-primary-rgb), 0.25);
 }
 
 .noUi-connect {
   background: currentColor;
 }
 
 .litepicker {
   --litepicker-month-weekday-color: var(--tblr-secondary);
   --litepicker-button-prev-month-color: var(--tblr-secondary);
   --litepicker-button-next-month-color: var(--tblr-secondary);
   --litepicker-button-prev-month-color-hover: var(--tblr-primary);
   --litepicker-button-next-month-color-hover: var(--tblr-primary);
   --litepicker-day-color: var(--tblr-body-color);
   --litepicker-day-color-hover: var(--tblr-primary);
   --litepicker-is-end-color-bg: var(--tblr-primary);
   --litepicker-is-today-color: var(--tblr-primary);
   --litepicker-month-header-color: var(--tblr-body-color);
   --litepicker-container-months-color-bg: var(--tblr-bg-surface);
   font: inherit;
   -webkit-user-select: none;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
 }
 .litepicker svg {
   fill: none !important;
 }
 .litepicker .container__main {
   border: var(--tblr-border-width) var(--tblr-border-style) var(--tblr-border-color);
   border-radius: var(--tblr-border-radius);
   box-shadow: none;
 }
 .litepicker .container__months .month-item-name,
 .litepicker .container__months .month-item-year {
   font-weight: var(--tblr-font-weight-medium) !important;
 }
 .litepicker .container__months .button-next-month,
 .litepicker .container__months .button-prev-month {
   cursor: pointer !important;
 }
 .litepicker .container__months .month-item-weekdays-row > div {
   padding: 0.5rem 0 !important;
   font-size: 0.75rem;
 }
 .litepicker .container__days .day-item {
   cursor: pointer !important;
   padding: 0.5rem 0 !important;
   transition: color 0.3s, background-color 0.3s, border-color 0.3s;
 }
 @media (prefers-reduced-motion: reduce) {
   .litepicker .container__days .day-item {
     transition: none;
   }
 }
 .datepicker-inline .litepicker {
   box-shadow: var(--tblr-box-shadow-input);
 }
 .datepicker-inline .litepicker .container__months {
   box-shadow: none;
   background-color: var(--tblr-bg-forms);
 }
 
 /**
  * Tom Select bootstrap 5
  */
 /**
  * tom-select.css (v//@@version)
  * Copyright (c) contributors
  *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this
  * file except in compliance with the License. You may obtain a copy of the License at:
  * http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software distributed under
  * the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
  * ANY KIND, either express or implied. See the License for the specific language
  * governing permissions and limitations under the License.
  *
  */
 :root {
   --ts-pr-clear-button:	0;
   --ts-pr-caret:	0;
   --ts-pr-min:	.75rem;
 }
 
 .ts-wrapper.single .ts-control, .ts-wrapper.single .ts-control input {
   cursor: pointer;
 }
 
 .ts-control {
   padding-right: max(var(--ts-pr-min), var(--ts-pr-clear-button) + var(--ts-pr-caret)) !important;
 }
 
 .ts-wrapper.plugin-drag_drop.multi > .ts-control > div.ui-sortable-placeholder {
   visibility: visible !important;
   background: #f2f2f2 !important;
   background: rgba(0, 0, 0, 0.06) !important;
   border: 0 none !important;
   box-shadow: inset 0 0 12px 4px #fff;
 }
 .ts-wrapper.plugin-drag_drop .ui-sortable-placeholder::after {
   content: "!";
   visibility: hidden;
 }
 .ts-wrapper.plugin-drag_drop .ui-sortable-helper {
   box-shadow: 0 2px 5px rgba(0, 0, 0, 0.2);
 }
 
 .plugin-checkbox_options .option input {
   margin-right: 0.5rem;
 }
 
 .plugin-clear_button {
   --ts-pr-clear-button: 1em;
 }
 .plugin-clear_button .clear-button {
   opacity: 0;
   position: absolute;
   top: 50%;
   transform: translateY(-50%);
   right: calc(0.75rem - 5px);
   margin-right: 0 !important;
   background: transparent !important;
   transition: opacity 0.5s;
   cursor: pointer;
 }
 .plugin-clear_button.form-select .clear-button, .plugin-clear_button.single .clear-button {
   right: max( var(--ts-pr-caret), 0.75rem);
 }
 .plugin-clear_button.focus.has-items .clear-button, .plugin-clear_button:not(.disabled):hover.has-items .clear-button {
   opacity: 1;
 }
 
 .ts-wrapper .dropdown-header {
   position: relative;
   padding: 6px 0.75rem;
   border-bottom: 1px solid #d0d0d0;
   background: #f8f8f8;
   border-radius: var(--tblr-border-radius) var(--tblr-border-radius) 0 0;
 }
 .ts-wrapper .dropdown-header-close {
   position: absolute;
   right: 0.75rem;
   top: 50%;
   color: #182433;
   opacity: 0.4;
   margin-top: -12px;
   line-height: 20px;
   font-size: 20px !important;
 }
 .ts-wrapper .dropdown-header-close:hover {
   color: black;
 }
 
 .plugin-dropdown_input.focus.dropdown-active .ts-control {
   box-shadow: none;
   border: 1px solid var(--tblr-border-color);
   box-shadow: var(--tblr-box-shadow-input);
 }
 .plugin-dropdown_input .dropdown-input {
   border: 1px solid #d0d0d0;
   border-width: 0 0 1px 0;
   display: block;
   padding: 0.5625rem 0.75rem;
   box-shadow: none;
   width: 100%;
   background: transparent;
 }
 .plugin-dropdown_input.focus .ts-dropdown .dropdown-input {
   border-color: #80aad3;
   outline: 0;
   box-shadow: var(--tblr-box-shadow-input), 0 0 0 0.25rem rgba(var(--tblr-primary-rgb), 0.25);
 }
 .plugin-dropdown_input .items-placeholder {
   border: 0 none !important;
   box-shadow: none !important;
   width: 100%;
 }
 .plugin-dropdown_input.has-items .items-placeholder, .plugin-dropdown_input.dropdown-active .items-placeholder {
   display: none !important;
 }
 
 .ts-wrapper.plugin-input_autogrow.has-items .ts-control > input {
   min-width: 0;
 }
 .ts-wrapper.plugin-input_autogrow.has-items.focus .ts-control > input {
   flex: none;
   min-width: 4px;
 }
 .ts-wrapper.plugin-input_autogrow.has-items.focus .ts-control > input::-webkit-input-placeholder {
   color: transparent;
 }
 .ts-wrapper.plugin-input_autogrow.has-items.focus .ts-control > input:-ms-input-placeholder {
   color: transparent;
 }
 .ts-wrapper.plugin-input_autogrow.has-items.focus .ts-control > input::-ms-input-placeholder {
   color: transparent;
 }
 .ts-wrapper.plugin-input_autogrow.has-items.focus .ts-control > input::placeholder {
   color: transparent;
 }
 
 .ts-dropdown.plugin-optgroup_columns .ts-dropdown-content {
   display: flex;
 }
 .ts-dropdown.plugin-optgroup_columns .optgroup {
   border-right: 1px solid #f2f2f2;
   border-top: 0 none;
   flex-grow: 1;
   flex-basis: 0;
   min-width: 0;
 }
 .ts-dropdown.plugin-optgroup_columns .optgroup:last-child {
   border-right: 0 none;
 }
 .ts-dropdown.plugin-optgroup_columns .optgroup:before {
   display: none;
 }
 .ts-dropdown.plugin-optgroup_columns .optgroup-header {
   border-top: 0 none;
 }
 
 .ts-wrapper.plugin-remove_button .item {
   display: inline-flex;
   align-items: center;
   padding-right: 0 !important;
 }
 .ts-wrapper.plugin-remove_button .item .remove {
   color: inherit;
   text-decoration: none;
   vertical-align: middle;
   display: inline-block;
   padding: 0 5px;
   border-radius: 0 2px 2px 0;
   box-sizing: border-box;
 }
 .ts-wrapper.plugin-remove_button .item .remove:hover {
   background: rgba(0, 0, 0, 0.05);
 }
 .ts-wrapper.plugin-remove_button.disabled .item .remove:hover {
   background: none;
 }
 .ts-wrapper.plugin-remove_button .remove-single {
   position: absolute;
   right: 0;
   top: 0;
   font-size: 23px;
 }
 
 .ts-wrapper.plugin-remove_button:not(.rtl) .item .remove {
   border-left: 1px solid #dadfe5;
   margin-left: 5px;
 }
 .ts-wrapper.plugin-remove_button:not(.rtl) .item.active .remove {
   border-left-color: rgba(0, 0, 0, 0);
 }
 .ts-wrapper.plugin-remove_button:not(.rtl).disabled .item .remove {
   border-left-color: white;
 }
 
 .ts-wrapper.plugin-remove_button.rtl .item .remove {
   border-right: 1px solid #dadfe5;
   margin-right: 5px;
 }
 .ts-wrapper.plugin-remove_button.rtl .item.active .remove {
   border-right-color: rgba(0, 0, 0, 0);
 }
 .ts-wrapper.plugin-remove_button.rtl.disabled .item .remove {
   border-right-color: white;
 }
 
 .ts-wrapper {
   position: relative;
 }
 
 .ts-dropdown,
 .ts-control,
 .ts-control input {
   color: #182433;
   font-family: inherit;
   font-size: inherit;
   line-height: 1.4285714286;
   font-smoothing: inherit;
 }
 
 .ts-control,
 .ts-wrapper.single.input-active .ts-control {
   background: var(--tblr-bg-forms);
   cursor: text;
 }
 
 .ts-control {
   border: 1px solid var(--tblr-border-color);
   padding: 0.5625rem 0.75rem;
   width: 100%;
   overflow: hidden;
   position: relative;
   z-index: 1;
   box-sizing: border-box;
   box-shadow: none;
   border-radius: var(--tblr-border-radius);
   display: flex;
   flex-wrap: wrap;
 }
 .ts-wrapper.multi.has-items .ts-control {
   padding: calc( 0.5625rem - 1px - 0px) 0.75rem calc( 0.5625rem - 1px - 3px - 0px);
 }
 .full .ts-control {
   background-color: var(--tblr-bg-forms);
 }
 .disabled .ts-control, .disabled .ts-control * {
   cursor: default !important;
 }
 .focus .ts-control {
   box-shadow: none;
 }
 .ts-control > * {
   vertical-align: baseline;
   display: inline-block;
 }
 .ts-wrapper.multi .ts-control > div {
   cursor: pointer;
   margin: 0 3px 3px 0;
   padding: 1px 5px;
   background: #efefef;
   color: #182433;
   border: 0px solid #dadfe5;
 }
 .ts-wrapper.multi .ts-control > div.active {
   background: #0054a6;
   color: #fff;
   border: 0px solid rgba(0, 0, 0, 0);
 }
 .ts-wrapper.multi.disabled .ts-control > div, .ts-wrapper.multi.disabled .ts-control > div.active {
   color: #727272;
   background: white;
   border: 0px solid white;
 }
 .ts-control > input {
   flex: 1 1 auto;
   min-width: 7rem;
   display: inline-block !important;
   padding: 0 !important;
   min-height: 0 !important;
   max-height: none !important;
   max-width: 100% !important;
   margin: 0 !important;
   text-indent: 0 !important;
   border: 0 none !important;
   background: none !important;
   line-height: inherit !important;
   -webkit-user-select: auto !important;
      -moz-user-select: auto !important;
       -ms-user-select: auto !important;
           user-select: auto !important;
   box-shadow: none !important;
 }
 .ts-control > input::-ms-clear {
   display: none;
 }
 .ts-control > input:focus {
   outline: none !important;
 }
 .has-items .ts-control > input {
   margin: 0px 4px !important;
 }
 .ts-control.rtl {
   text-align: right;
 }
 .ts-control.rtl.single .ts-control:after {
   left: calc(0.75rem + 5px);
   right: auto;
 }
 .ts-control.rtl .ts-control > input {
   margin: 0px 4px 0px -2px !important;
 }
 .disabled .ts-control {
   opacity: 0.5;
   background-color: var(--tblr-bg-surface-secondary);
 }
 .input-hidden .ts-control > input {
   opacity: 0;
   position: absolute;
   left: -10000px;
 }
 
 .ts-dropdown {
   position: absolute;
   top: 100%;
   left: 0;
   width: 100%;
   z-index: 10;
   border: 1px solid #d0d0d0;
   background: #fff;
   margin: 0.25rem 0 0 0;
   border-top: 0 none;
   box-sizing: border-box;
   box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
   border-radius: 0 0 var(--tblr-border-radius) var(--tblr-border-radius);
 }
 .ts-dropdown [data-selectable] {
   cursor: pointer;
   overflow: hidden;
 }
 .ts-dropdown [data-selectable] .highlight {
   background: rgba(255, 237, 40, 0.4);
   border-radius: 1px;
 }
 .ts-dropdown .option,
 .ts-dropdown .optgroup-header,
 .ts-dropdown .no-results,
 .ts-dropdown .create {
   padding: 3px 0.75rem;
 }
 .ts-dropdown .option, .ts-dropdown [data-disabled], .ts-dropdown [data-disabled] [data-selectable].option {
   cursor: inherit;
   opacity: 0.5;
 }
 .ts-dropdown [data-selectable].option {
   opacity: 1;
   cursor: pointer;
 }
 .ts-dropdown .optgroup:first-child .optgroup-header {
   border-top: 0 none;
 }
 .ts-dropdown .optgroup-header {
   color: #667382;
   background: var(--tblr-bg-surface);
   cursor: default;
 }
 .ts-dropdown .active {
   background-color: rgba(var(--tblr-text-secondary-rgb), 0.04);
   color: inherit;
 }
 .ts-dropdown .active.create {
   color: inherit;
 }
 .ts-dropdown .create {
   color: rgba(24, 36, 51, 0.5);
 }
 .ts-dropdown .spinner {
   display: inline-block;
   width: 30px;
   height: 30px;
   margin: 3px 0.75rem;
 }
 .ts-dropdown .spinner:after {
   content: " ";
   display: block;
   width: 24px;
   height: 24px;
   margin: 3px;
   border-radius: 50%;
   border: 5px solid #d0d0d0;
   border-color: #d0d0d0 transparent #d0d0d0 transparent;
   animation: lds-dual-ring 1.2s linear infinite;
 }
 @keyframes lds-dual-ring {
   0% {
     transform: rotate(0deg);
   }
   100% {
     transform: rotate(360deg);
   }
 }
 
 .ts-dropdown-content {
   overflow-y: auto;
   overflow-x: hidden;
   max-height: 200px;
   overflow-scrolling: touch;
   scroll-behavior: smooth;
 }
 
 .ts-hidden-accessible {
   border: 0 !important;
   clip: rect(0 0 0 0) !important;
   -webkit-clip-path: inset(50%) !important;
           clip-path: inset(50%) !important;
   overflow: hidden !important;
   padding: 0 !important;
   position: absolute !important;
   width: 1px !important;
   white-space: nowrap !important;
 }
 
 .ts-wrapper.form-control,
 .ts-wrapper.form-select {
   padding: 0 !important;
   height: auto;
   box-shadow: none;
   display: flex;
 }
 
 .ts-dropdown,
 .ts-dropdown.form-control,
 .ts-dropdown.form-select {
   height: auto;
   padding: 0;
   z-index: 1000;
   background: #fff;
   border: 1px solid var(--tblr-border-color-translucent);
   border-radius: 4px;
   box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
 }
 
 .ts-dropdown .optgroup-header {
   font-size: 0.765625rem;
   line-height: 1.4285714286;
 }
 .ts-dropdown .optgroup:first-child:before {
   display: none;
 }
 .ts-dropdown .optgroup:before {
   content: " ";
   display: block;
   height: 0;
   margin: var(--tblr-spacer) 0;
   overflow: hidden;
   border-top: 1px solid var(--tblr-border-color-translucent);
   margin-left: -0.75rem;
   margin-right: -0.75rem;
 }
 .ts-dropdown .create {
   padding-left: 0.75rem;
 }
 
 .ts-dropdown-content {
   padding: 5px 0;
 }
 
 .ts-control {
   box-shadow: var(--tblr-box-shadow-input);
   transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
   display: flex;
   align-items: center;
 }
 @media (prefers-reduced-motion: reduce) {
   .ts-control {
     transition: none;
   }
 }
 .ts-control.dropdown -active {
   border-radius: var(--tblr-border-radius);
 }
 .focus .ts-control {
   border-color: #80aad3;
   outline: 0;
   box-shadow: var(--tblr-box-shadow-input), 0 0 0 0.25rem rgba(var(--tblr-primary-rgb), 0.25);
 }
 .ts-control .item {
   display: flex;
   align-items: center;
 }
 
 .ts-wrapper.is-invalid,
 .was-validated .invalid,
 .was-validated :invalid + .ts-wrapper {
   border-color: var(--tblr-form-invalid-color);
 }
 .ts-wrapper.is-invalid:not(.single),
 .was-validated .invalid:not(.single),
 .was-validated :invalid + .ts-wrapper:not(.single) {
   background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24' fill='none' stroke='%23d63939' stroke-width='2' stroke-linecap='round' stroke-linejoin='round'%3e%3cline x1='18' y1='6' x2='6' y2='18'%3e%3c/line%3e%3cline x1='6' y1='6' x2='18' y2='18'%3e%3c/line%3e%3c/svg%3e");
   background-position: right calc(0.3571428572em + 0.28125rem) center;
   background-size: calc(0.7142857143em + 0.5625rem) calc(0.7142857143em + 0.5625rem);
   background-repeat: no-repeat;
 }
 .ts-wrapper.is-invalid.single,
 .was-validated .invalid.single,
 .was-validated :invalid + .ts-wrapper.single {
   background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3e%3cpath fill='none' stroke='%23929dab' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='m2 5 6 6 6-6'/%3e%3c/svg%3e"), url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24' fill='none' stroke='%23d63939' stroke-width='2' stroke-linecap='round' stroke-linejoin='round'%3e%3cline x1='18' y1='6' x2='6' y2='18'%3e%3c/line%3e%3cline x1='6' y1='6' x2='18' y2='18'%3e%3c/line%3e%3c/svg%3e");
   background-position: right 0.75rem center, center right 2.25rem;
   background-size: 16px 12px, calc(0.7142857143em + 0.5625rem) calc(0.7142857143em + 0.5625rem);
   background-repeat: no-repeat;
 }
 .ts-wrapper.is-invalid.focus .ts-control,
 .was-validated .invalid.focus .ts-control,
 .was-validated :invalid + .ts-wrapper.focus .ts-control {
   border-color: var(--tblr-form-invalid-color);
   box-shadow: 0 0 0 0.25rem rgba(var(--tblr-form-invalid-color), 0.25);
 }
 
 .ts-wrapper.is-valid,
 .was-validated .valid,
 .was-validated :valid + .ts-wrapper {
   border-color: var(--tblr-form-valid-color);
 }
 .ts-wrapper.is-valid:not(.single),
 .was-validated .valid:not(.single),
 .was-validated :valid + .ts-wrapper:not(.single) {
   background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24' fill='none' stroke='%232fb344' stroke-width='2' stroke-linecap='round' stroke-linejoin='round'%3e%3cpolyline points='20 6 9 17 4 12'%3e%3c/polyline%3e%3c/svg%3e");
   background-position: right calc(0.3571428572em + 0.28125rem) center;
   background-size: calc(0.7142857143em + 0.5625rem) calc(0.7142857143em + 0.5625rem);
   background-repeat: no-repeat;
 }
 .ts-wrapper.is-valid.single,
 .was-validated .valid.single,
 .was-validated :valid + .ts-wrapper.single {
   background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3e%3cpath fill='none' stroke='%23929dab' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='m2 5 6 6 6-6'/%3e%3c/svg%3e"), url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='24' height='24' viewBox='0 0 24 24' fill='none' stroke='%232fb344' stroke-width='2' stroke-linecap='round' stroke-linejoin='round'%3e%3cpolyline points='20 6 9 17 4 12'%3e%3c/polyline%3e%3c/svg%3e");
   background-position: right 0.75rem center, center right 2.25rem;
   background-size: 16px 12px, calc(0.7142857143em + 0.5625rem) calc(0.7142857143em + 0.5625rem);
   background-repeat: no-repeat;
 }
 .ts-wrapper.is-valid.focus .ts-control,
 .was-validated .valid.focus .ts-control,
 .was-validated :valid + .ts-wrapper.focus .ts-control {
   border-color: var(--tblr-form-valid-color);
   box-shadow: 0 0 0 0.25rem rgba(var(--tblr-form-valid-color), 0.25);
 }
 
 .ts-wrapper {
   min-height: calc(1.4285714286em + 1.125rem + calc(var(--tblr-border-width) * 2));
   display: flex;
 }
 .input-group-sm > .ts-wrapper, .ts-wrapper.form-select-sm, .ts-wrapper.form-control-sm {
   min-height: calc(1.4285714286em + 0.25rem + calc(var(--tblr-border-width) * 2));
 }
 .input-group-sm > .ts-wrapper .ts-control, .ts-wrapper.form-select-sm .ts-control, .ts-wrapper.form-control-sm .ts-control {
   border-radius: var(--tblr-border-radius-sm);
   font-size: 0.75rem;
 }
 .input-group-sm > .ts-wrapper.has-items .ts-control, .ts-wrapper.form-select-sm.has-items .ts-control, .ts-wrapper.form-control-sm.has-items .ts-control {
   font-size: 0.75rem;
   padding-bottom: 0;
 }
 .input-group-sm > .ts-wrapper.multi.has-items .ts-control, .ts-wrapper.form-select-sm.multi.has-items .ts-control, .ts-wrapper.form-control-sm.multi.has-items .ts-control {
   padding-top: calc((calc(1.4285714286em + 0.25rem + calc(var(--tblr-border-width) * 2)) - (1.4285714286 * 0.75rem) - 4px) / 2) !important;
 }
 .ts-wrapper.multi.has-items .ts-control {
   padding-left: calc(0.75rem - 5px);
   --ts-pr-min: calc(0.75rem - 5px);
 }
 .ts-wrapper.multi .ts-control > div {
   border-radius: calc(var(--tblr-border-radius) - 1px);
 }
 .input-group-lg > .ts-wrapper, .ts-wrapper.form-control-lg, .ts-wrapper.form-select-lg {
   min-height: calc(1.4285714286em + 1rem + calc(var(--tblr-border-width) * 2));
 }
 .input-group-lg > .ts-wrapper .ts-control, .ts-wrapper.form-control-lg .ts-control, .ts-wrapper.form-select-lg .ts-control {
   border-radius: var(--tblr-border-radius-lg);
   font-size: 1.25rem;
 }
 
 .ts-wrapper:not(.form-control):not(.form-select) {
   padding: 0;
   border: none;
   height: auto;
   box-shadow: none;
   background: none;
 }
 .ts-wrapper:not(.form-control):not(.form-select).single .ts-control {
   background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3e%3cpath fill='none' stroke='%23929dab' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='m2 5 6 6 6-6'/%3e%3c/svg%3e");
   background-repeat: no-repeat;
   background-position: right 0.75rem center;
   background-size: 16px 12px;
 }
 .ts-wrapper.form-select, .ts-wrapper.single {
   --ts-pr-caret: 2.25rem;
 }
 
 .ts-wrapper.form-control .ts-control, .ts-wrapper.form-control.single.input-active .ts-control,
 .ts-wrapper.form-select .ts-control,
 .ts-wrapper.form-select.single.input-active .ts-control {
   border: none !important;
 }
 .ts-wrapper.form-control:not(.disabled) .ts-control, .ts-wrapper.form-control:not(.disabled).single.input-active .ts-control,
 .ts-wrapper.form-select:not(.disabled) .ts-control,
 .ts-wrapper.form-select:not(.disabled).single.input-active .ts-control {
   background: transparent !important;
 }
 
 .input-group > .ts-wrapper {
   flex-grow: 1;
 }
 .input-group > .ts-wrapper:not(:nth-child(2)) > .ts-control {
   border-top-left-radius: 0;
   border-bottom-left-radius: 0;
 }
 .input-group > .ts-wrapper:not(:last-child) > .ts-control {
   border-top-right-radius: 0;
   border-bottom-right-radius: 0;
 }
 
 :root {
   --ts-pr-clear-button: 0rem;
   --ts-pr-caret: 0rem;
 }
 
 .ts-input {
   color: inherit;
 }
 
 .ts-control {
   color: inherit;
 }
 .ts-control .dropdown-menu {
   width: 100%;
   height: auto;
 }
 
 .ts-wrapper .form-control,
 .ts-wrapper .form-select, .ts-wrapper.form-control, .ts-wrapper.form-select {
   box-shadow: var(--tblr-box-shadow-input);
 }
 .ts-wrapper.is-invalid .ts-control, .ts-wrapper.is-valid .ts-control {
   --ts-pr-clear-button: 1.5rem;
 }
 
 .ts-dropdown {
   background: var(--tblr-bg-surface);
   color: var(--tblr-body-color);
   box-shadow: var(--tblr-box-shadow-dropdown);
 }
 .ts-dropdown .option {
   padding: 0.5rem 0.75rem;
 }
 
 .ts-control,
 .ts-control input {
   color: var(--tblr-body-color);
 }
 
 .ts-control input::-webkit-input-placeholder {
   color: #929dab;
 }
 
 .ts-control input:-ms-input-placeholder {
   color: #929dab;
 }
 
 .ts-control input::-ms-input-placeholder {
   color: #929dab;
 }
 
 .ts-control input::placeholder {
   color: #929dab;
 }
 
 .ts-wrapper.multi .ts-control > div {
   background: var(--tblr-bg-surface-secondary);
   border: 1px solid var(--tblr-border-color);
   color: var(--tblr-body-color);
 }
 
 .apexcharts-tooltip {
   color: var(--tblr-light) !important;
   background: var(--tblr-bg-surface-dark) !important;
   font-size: 0.765625rem !important;
   padding: 0.25rem !important;
   box-shadow: none !important;
 }
 
 .apexcharts-tooltip-title {
   background: transparent !important;
   border: 0 !important;
   margin: 0 !important;
   font-weight: var(--tblr-font-weight-bold);
   padding: 0.25rem 0.5rem !important;
 }
 
 .apexcharts-tooltip-y-group {
   padding: 2px 0 !important;
 }
 
 .apexcharts-tooltip-series-group {
   padding: 0 0.5rem 0 !important;
 }
 
 .apexcharts-tooltip-marker {
   width: 10px !important;
   height: 10px !important;
 }
 
 .apexcharts-text {
   fill: var(--tblr-body-color) !important;
 }
 
 .apexcharts-gridline {
   stroke: var(--tblr-border-color) !important;
 }
 
 .apexcharts-legend-text {
   color: inherit !important;
 }
 
 .apexcharts-radialbar-area {
   stroke: var(--tblr-border-color-dark) !important;
 }
 
 svg {
   touch-action: none;
 }
 
 image, text, .jvm-zoomin, .jvm-zoomout {
   -webkit-user-select: none;
   -moz-user-select: none;
   -ms-user-select: none;
   user-select: none;
 }
 
 .jvm-container {
   touch-action: none;
   position: relative;
   overflow: hidden;
   height: 100%;
   width: 100%;
 }
 
 .jvm-tooltip {
   border-radius: 3px;
   background-color: #5c5cff;
   font-family: sans-serif, Verdana;
   font-size: smaller;
   box-shadow: 1px 2px 12px rgba(0, 0, 0, 0.2);
   padding: 3px 5px;
   white-space: nowrap;
   position: absolute;
   display: none;
   color: #FFF;
 }
 
 .jvm-tooltip.active {
   display: block;
 }
 
 .jvm-zoom-btn {
   border-radius: 3px;
   background-color: #292929;
   padding: 3px;
   box-sizing: border-box;
   position: absolute;
   line-height: 10px;
   cursor: pointer;
   color: #FFF;
   height: 15px;
   width: 15px;
   left: 10px;
 }
 
 .jvm-zoom-btn.jvm-zoomout {
   top: 30px;
 }
 
 .jvm-zoom-btn.jvm-zoomin {
   top: 10px;
 }
 
 .jvm-series-container {
   right: 15px;
   position: absolute;
 }
 
 .jvm-series-container.jvm-series-h {
   bottom: 15px;
 }
 
 .jvm-series-container.jvm-series-v {
   top: 15px;
 }
 
 .jvm-series-container .jvm-legend {
   background-color: #FFF;
   border: 1px solid #e5e7eb;
   margin-left: 0.75rem;
   border-radius: 0.25rem;
   border-color: #e5e7eb;
   padding: 0.6rem;
   box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
   float: left;
 }
 
 .jvm-series-container .jvm-legend .jvm-legend-title {
   line-height: 1;
   border-bottom: 1px solid #e5e7eb;
   padding-bottom: 0.5rem;
   margin-bottom: 0.575rem;
   text-align: left;
 }
 
 .jvm-series-container .jvm-legend .jvm-legend-inner {
   overflow: hidden;
 }
 
 .jvm-series-container .jvm-legend .jvm-legend-inner .jvm-legend-tick {
   overflow: hidden;
   min-width: 40px;
 }
 
 .jvm-series-container .jvm-legend .jvm-legend-inner .jvm-legend-tick:not(:first-child) {
   margin-top: 0.575rem;
 }
 
 .jvm-series-container .jvm-legend .jvm-legend-inner .jvm-legend-tick .jvm-legend-tick-sample {
   border-radius: 4px;
   margin-right: 0.65rem;
   height: 16px;
   width: 16px;
   float: left;
 }
 
 .jvm-series-container .jvm-legend .jvm-legend-inner .jvm-legend-tick .jvm-legend-tick-text {
   font-size: 12px;
   text-align: center;
   float: left;
 }
 
 .jvm-line[animation=true] {
   animation: jvm-line-animation 10s linear forwards infinite;
 }
 @keyframes jvm-line-animation {
   from {
     stroke-dashoffset: 250;
   }
 }
 .jvm-tooltip {
   background: #182433;
   font-family: inherit;
   font-size: 0.75rem;
   box-shadow: var(--tblr-shadow-card);
 }
 
 .jvm-series-container .jvm-legend .jvm-legend-title {
   border-bottom: 0;
   font-weight: var(--tblr-font-weight-medium);
 }
 
 .jvm-series-container .jvm-legend {
   background-color: var(--tblr-card-bg, var(--tblr-bg-surface));
   border: var(--tblr-border-width) var(--tblr-border-style) var(--tblr-border-color);
   min-width: 8rem;
 }
 .jvm-series-container .jvm-legend .jvm-legend-inner .jvm-legend-tick {
   display: flex;
   align-items: center;
 }
 .jvm-series-container .jvm-legend .jvm-legend-inner .jvm-legend-tick .jvm-legend-tick-sample {
   width: 0.75rem;
   height: 0.75rem;
 }
 
 .jvm-zoom-btn {
   border: var(--tblr-border-width) var(--tblr-border-style) var(--tblr-border-color);
   background: var(--tblr-card-bg, var(--tblr-bg-surface));
   color: var(--tblr-body-color);
   padding: 0;
   display: flex;
   align-items: center;
   justify-content: center;
   line-height: 1;
   width: 1.5rem;
   height: 1.5rem;
   font-size: 1rem;
   box-shadow: var(--tblr-shadow-card);
 }
 .jvm-zoom-btn.jvm-zoomout {
   top: 2.5rem;
 }
 
 .dropzone {
   border: var(--tblr-border-width) dashed var(--tblr-border-color);
   color: var(--tblr-secondary);
   padding: 1rem;
 }
 .dropzone.dz-drag-hover {
   border: var(--tblr-border-width) dashed var(--tblr-primary);
   background: rgba(var(--tblr-primary-rgb), 0.01);
   color: var(--tblr-primary);
 }
 .dropzone.dz-drag-hover .dz-message {
   opacity: 1;
 }
 .dropzone .dz-preview {
   margin: 0.5rem;
 }
 .dropzone .dz-preview .dz-image {
   border-radius: var(--tblr-border-radius);
 }
 .dropzone .dz-preview .dz-success-mark {
   height: 54px;
 }
 
 .fslightbox-container {
   font-family: inherit !important;
   background: rgba(24, 36, 51, 0.24) !important;
   -webkit-backdrop-filter: blur(4px) !important;
           backdrop-filter: blur(4px) !important;
 }
 
 .fslightbox-slide-number-container {
   color: inherit !important;
 }
 
 .fslightbox-slash {
   background: currentColor !important;
 }
 
 body {
   --plyr-color-main: var(--tblr-primary);
 }
 
 .tox-tinymce {
   border: var(--tblr-border-width) var(--tblr-border-style) var(--tblr-border-color) !important;
   border-radius: 4px !important;
   font-family: var(--tblr-font-sans-serif) !important;
 }
 
 .tox-toolbar__group {
   padding: 0 0.5rem 0;
 }
 
 .tox .tox-toolbar__primary {
   background: transparent !important;
 }
 
 .tox:not(.tox-tinymce-inline) .tox-editor-header {
   border-bottom: var(--tblr-border-width) var(--tblr-border-style) var(--tblr-border-color) !important;
   box-shadow: none !important;
   padding: 0 !important;
 }
 
 .tox-tbtn {
   margin: 0 !important;
 }
 
 .tox-statusbar {
   border-top: var(--tblr-border-width) var(--tblr-border-style) var(--tblr-border-color) !important;
 }
 
 .tox .tox-toolbar-overlord,
 .tox:not(.tox-tinymce-inline) .tox-editor-header {
   background: transparent !important;
 }
 
 :root {
   --gl-star-size: auto;
   --gl-star-color: var(--tblr-yellow);
   --gl-star-color-inactive: var(--tblr-border-color);
 }
 
 [data-star-rating] svg {
   width: var(--tblr-icon-size, --gl-star-size);
   height: var(--tblr-icon-size, --gl-star-size);
 }
 [data-star-rating] :not(.gl-active) > .gl-star-full {
   color: var(--gl-star-color-inactive) !important;
 }
 [data-star-rating] .gl-active > .gl-star-full {
   color: var(--gl-star-color);
 }
 
 .clr-picker {
   box-shadow: var(--tblr-box-shadow-dropdown);
   background-color: var(--tblr-bg-surface);
 }
 
 input.clr-color {
   border-radius: var(--tblr-border-radius);
   color: var(--tblr-body-color);
   border-color: var(--tblr-border-color);
   background: transparent;
 }
 input.clr-color:focus {
   outline: 0;
   box-shadow: 0 0 0 0.25rem rgba(var(--tblr-primary-rgb), 0.25);
   border-color: rgba(var(--tblr-primary-rgb), 0.25);
 }
 
 .clr-swatches button {
   border-radius: var(--tblr-border-radius);
   padding: 0 2px 4px 2px;
 }
 .clr-swatches button:focus {
   outline: 0;
   box-shadow: 0 0 0 0.25rem rgba(var(--tblr-primary-rgb), 0.25);
 }
 
 .clr-preview {
   border-radius: var(--tblr-border-radius);
   overflow: visible;
 }
 .clr-preview button, .clr-preview:before, .clr-preview:after {
   border-radius: var(--tblr-border-radius);
 }
 .clr-preview button:focus {
   outline: 0;
   box-shadow: 0 0 0 0.25rem rgba(var(--tblr-primary-rgb), 0.25);
 }
 
 .clr-field {
   display: block;
 }
 .clr-field button {
   width: 1.5rem;
   height: 1.5rem;
   left: 6px;
   right: auto;
   border-radius: var(--tblr-border-radius);
 }
 .clr-field button:after {
   box-shadow: inset 0 0 0 1px var(--tblr-border-color-translucent);
 }
 .clr-field button:focus {
   outline: 0;
   box-shadow: 0 0 0 0.25rem rgba(var(--tblr-primary-rgb), 0.25);
 }
 .clr-field input {
   padding-left: 2.5rem;
 }
