{% include "django/forms/widgets/input.html" %}
{% if url_valid %}
    <small class="ms-1">
        {{ current_label }} <a href="{{ widget.href }}" target="_blank">{{ widget.value }}</a>
    </small>
{% endif %}
