{% load i18n %}
<hr class="mb-3 mt-1" />
<details data-filter-title="{{ title }}" open>
    <summary class="subheader mb-2 text-blue">
        {% blocktranslate with filter_title=title %} By {{ filter_title }} {% endblocktranslate %}
    </summary>
    <div class="list-group list-group-transparent mb-3">
        {% for choice in choices %}
            <a class="list-group-item list-group-item-action d-flex align-items-center important {% if choice.selected %} active{% endif %}"
               href="{{ choice.query_string|iriencode }}">
                {{ choice.display }}
            </a>
        {% endfor %}
    </div>
</details>
