{% extends "admin/base.html" %}
{% block title %}{% spaceless %}
    {{ site_title|default:_('Django site admin') }} | {{ title }} {% if subtitle %} | {{ subtitle }}{% endif %}
{% endspaceless %}{% endblock title %}
{% block nav-global %}
{% endblock nav-global %}
