<div class="row g-2">
  {% for group_name, group_choices, group_index in widget.optgroups %}
    {% for option in group_choices %}
      <div class="col-auto">
        <label class="form-colorinput">
          <input name="{{ option.name }}" type="radio" value="{{ option.value }}" class="form-colorinput-input" {% if option.selected %}checked{% endif %}>
          <span class="form-colorinput-color bg-{{ option.value }}"></span>
        </label>
      </div>
    {% endfor %}
  {% endfor %}
</div>
